@@ -1,12 +1,18 @@
 """Clock implementation using different backend
 """
+from __future__ import annotations
+
 import sqlite3
 from time import monotonic
 from time import time
+from typing import TYPE_CHECKING
 
 from .abstracts import AbstractClock
 from .utils import dedicated_sqlite_clock_connection
 
+if TYPE_CHECKING:
+    from psycopg_pool import ConnectionPool
+
 
 class MonotonicClock(AbstractClock):
     def __init__(self):
@@ -45,3 +51,22 @@ class SQLiteClock(AbstractClock):
     def now(self) -> int:
         now = self.conn.execute(self.time_query).fetchone()[0]
         return int(now)
+
+
+class PostgresClock(AbstractClock):
+    """Get timestamp using Postgres as remote clock backend"""
+
+    def __init__(self, pool: 'ConnectionPool'):
+        self.pool = pool
+
+    def now(self) -> int:
+        value = 0
+
+        with self.pool.connection() as conn:
+            with conn.cursor() as cur:
+                cur.execute("SELECT EXTRACT(epoch FROM current_timestamp) * 1000")
+                result = cur.fetchone()
+                assert result, "unable to get current-timestamp from postgres"
+                value = int(result[0])
+
+        return value
